.guilabel
  background-color: var(--color-guilabel-background)
  border: 1px solid var(--color-guilabel-border)
  color: var(--color-guilabel-text)

  padding: 0 0.3em
  border-radius: 0.5em
  font-size: 0.9em
