@forward "admonitions"
@forward "api"
@forward "blocks"
@forward "captions"
@forward "code"
@forward "footnotes"
@forward "images"
@forward "indexes"
@forward "lists"
@forward "math"
@forward "misc"
@forward "rubrics"
@forward "sidebar"
@forward "tables"
@forward "target"
@forward "gui-labels"
